==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/user.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("$CONF[G_PATH]/include/kmod/user_list/index.php");
unset($user);
unset($login);

settype($act, "string");
settype($uid, "integer");
settype($where, "string");
settype($index, "string");
settype($opt, "string");

if ($act == _USER_ADD) {
	KWL_CheckNewUser($name,$email);
	$pass = trim($pass);
	$sql  = "INSERT INTO T_Users (user_level, name, pass, email, rdate) ";
	$sql .= "VALUES ($user_level, '$name', '". crypt($pass) ."', '$email', now())";
	if (SqlQuery($sql)) {
		$msg = _USER_ADDED;
		if ($mailtouser) KWL_MailToUser($name,$pass,$email);
	} else KWL_ShowError(_SQL_ERROR);

} else if ($act == "edit") {
	if ($uid) $user = KWL_GetUserInfo("uid",$uid);

} else if ($act == _USER_EDIT) {
	if ($name != $oldname)
	 if (KWL_GetUserInfo("name",$name)) KWL_ShowError(_USER_REGISTER3);
	$sql = "UPDATE T_Users SET user_level = '$user_level', name = '$name', ";
	$sql .= "email = '$email' ";
	if ($passwd) $sql .= ", pass = '". crypt($passwd) ."' ";
	$sql .= "WHERE uid = '$uid'";
	if (SqlQuery($sql)) {
		$msg = _UPDATED_USERDB;
	} else KWL_ShowError(_SQL_ERROR);

} else if ($act == _USER_KILL) {
	$sql = "DELETE FROM T_Users WHERE uid = '$uid'";
	if (SqlQuery($sql)) $msg = _USER_DELETED;
	else KWL_ShowError(_SQL_ERROR);

} else if ($uid) {
	$user = KWL_GetUserInfo("uid",$uid);
}

include("../include/header.inc.php");

$total_user = SqlCount("T_Users");
$moder = SqlCount("T_Users","user_level",1);
$smoder = SqlCount("T_Users","user_level",2);

$out = new KWL_Html;
$A['Heading'] = _USER_ADMIN;
$A['Content'] = "
<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" width=\"100%\">
<tr><td>
<ul>
	<li><a href=\"user.php?act=ulist&opt=n\">". _NORMAL_USER ."</a>: " . ($total_user - ($moder + $smoder)) . "</li>
	<li><a href=\"user.php?act=ulist&opt=m\">". _MODERATOR ."</a>: $moder </li>
	<li><a href=\"user.php?act=ulist&opt=s\">". _SCORE_MODERATOR ."</a>: $smoder </li>
	<li><a href=\"user.php?act=ulist&opt=t\">". _TOTAL ."</a>: $total_user </li>
</ul>
</td></tr></table>".
$out->form_start("admin/user.php","adduser").
$out->table_start("100%",'',0,0,3)."
<tr>
	<td>". _LEVEL .":</td>
   <td>". $out->select("user_level", array (0 => _NORMAL_USER,
                                            1 => _MODERATOR,
                                            2 => _SCORE_MODERATOR),0) ."
</td>
</tr>
<tr>
   <td>* ". _NAME .":</td>
   <td>". $out->input_form("text","name",'',KWL_FormSize(10),50) ."</td>
</tr>   
<tr>
   <td>* ". _EMAIL .":</td>
   <td>". $out->input_form("text","email",'',KWL_FormSize(10),60) ."</td>
</tr>   
<tr>
   <td>* ". _PASSWD .":</td>
   <td>". $out->input_form("text","pass",'',KWL_FormSize(10),13) ."</td>
</tr>   
<tr>
   <td colspan=\"2\">". _SENDMAIL .": ".
   $out->check_box("mailtouser") ."</td>
</tr>   
<tr>
	<td COLSPAN=2>". $out->input_form("submit","act",_USER_ADD) ."</td>
</tr>". $out->table_end() . $out->form_end();
$A['Content'] .= KWL_MakeUserIndex("$CONF[G_URL]/admin/user.php?act=ulist");
KWL_DrawMain($A);

if (!empty($where)) $tmp = htmlspecialchars(stripslashes($index));
else $tmp = "";
$C['Heading'] = "<a name=\"finduser\">". _FIND_USER ."</a>";
$C['Content'] = "<center><br>". $out->form_start("admin/user.php#finduser","finduser").
                $out->input_form("TEXT","index",$tmp,$size['name'],60) ."&nbsp;".
                $out->select("where", array( "name"     => _NAME,
                                             "email"    => _EMAIL,
                                             "url"      => _URL,
                                             "user_sig" => _USER_SIG,
                                             "profile"  => _USER_PROF ), $where).
                $out->input_form("HIDDEN","what","finduser").
                $out->input_form("SUBMIT",'',_FIND).
                $out->form_end() . "</center><br>";
KWL_DrawMain($C);
unset($C);

if ($index) user_list_admin("",$index);
elseif ($act == "ulist") user_list_admin($opt);
elseif (is_array($user)) edit_user($user);

function user_list_admin($opt,$index="",$plimit=15) {
	global $CONF,$page,$where;

	$sql = "FROM T_Users WHERE ";	
	if (!empty($index)) {
      if (!empty($where)) {
         $sql .= "($where LIKE \"%". $index ."%\") ORDER BY uid DESC";
      } elseif(KWL_CheckHangul($index)) {
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "ī";
			if($index == "ī") $r = "Ÿ";
			if($index == "Ÿ") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = chr(0xfe);
			$sql .= "binary name BETWEEN binary '$index' AND binary '$r'";
		} elseif ($index == "other") {
         $sql .= "name REGEXP \"^\[1-9\.]\" ORDER BY uid DESC";
      } else $sql .= "name REGEXP \"^". $index ."\" ORDER BY uid DESC";
		$link = "user.php?index=$index";
	} else {
		if ($opt == "m") $sql .= "user_level = 1 ";
		elseif ($opt == "n") $sql .= "user_level = 0 ";
		elseif ($opt == "s") $sql .= "user_level = 2 ";
		else $sql .= "uid > 0 ";
		$sql .= "ORDER BY uid ASC ";
		$link = "user.php?act=ulist&opt=$opt";
	}

	if (empty($page)) $page = 1;
	$num_user = SqlResult("SELECT COUNT(*)" . $sql);
	$page_start = ($plimit * $page) - $plimit;
	$blah = KWL_npLink($num_user,$page,$link,$plimit);	
	
	$C['Content'] = $blah ? "<CENTER>$blah</CENTER>\n" : "";
	
	$result = SqlQuery("SELECT * " . $sql . " LIMIT $page_start,$plimit");

	$C['Content'] .= "<table border=\"1\" cellspacing=\"0\" cellpadding=\"3\" width=\"100%\"><tr>
	<th>Uid</th>
	<th>". _LEVEL ."</th>
	<th>". _NAME ."</th>
	<th>". _EMAIL ."</th>
	<th>". _RDATE ."</th>
	<th>&nbsp;</th>";
	while ($A = mysql_fetch_array($result)) {
		if ($A['user_level'] == 0) $tmp = _NORMAL_USER;
		elseif ($A['user_level'] == 1) $tmp = _MODERATOR;
		else $tmp = _SCORE_MODERATOR;
		$C['Content'] .= "<tr>
		<td>$A[uid]</td>
		<td>$tmp</td>
		<td><a href=\"$CONF[G_URL]/profiles.php?uid=$A[uid]\">". KWL_PrepareHtml($A['name']) ."</a></td>
		<td>$A[email]</td>
		<td>$A[rdate]</td>
		<td><a onclick=\"return getconfirm();\" href=\"user.php?act=". _USER_KILL ."&amp;uid=$A[uid]\"><img src=\"$CONF[img_url]/kill.gif\" alt=\"kill\" border=\"0\" /></a>&nbsp;<a href=\"user.php?act=edit&amp;uid=$A[uid]#edituser\"><img src=\"$CONF[img_url]/edit.gif\" alt=\"edit\" border=\"0\" /></a></td>";
	}
$C['Heading'] = "User List";
$C['Content'] .= "</tr></table>";
if ($blah) $C['Content'] .= "<center>$blah</center>\n";
KWL_DrawMain($C);
}

function edit_user($user) {

$out = new KWL_Html;
$A['Heading'] = "<a name=\"edituser\">". _USER_INFO ."</a>";
$A['Content'] = $out->form_start("admin/user.php","edituser") .
                $out->table_start("100%",'',0,0,3) ."
<tr>
	<td>Uid:</td><td>$user[uid]</td>
</tr>   
<tr>
	<td>". _RDATE ."</td>
   <td>$user[rdate]</td>
</tr>
<tr>
	<td>". _LEVEL .":</td>
   <td>". $out->select("user_level",array( 0 => _NORMAL_USER,
                                           1 => _MODERATOR,
                                           2 => _SCORE_MODERATOR ), $user['user_level']) ."
	</td>
</tr>   
<tr>
   <td>". _NAME .":</td>
   <td>". $out->input_form("text","name",KWL_PrepareHtml($user['name']),KWL_FormSize(10),50) ."
   </td>
</tr>   
<tr>
   <td>". _EMAIL .":</td>
   <td>". $out->input_form("text","email",KWL_PrepareHtml($user['email']),KWL_FormSize(10),60) ."   </td>
</tr>   
<tr>
   <td>". _PASSWD .":</td>
   <td>". $out->input_form("text","passwd",'',KWL_FormSize(10),13) ."
   <br />(". _PASS_CHANGE .")</td>
</tr>   
<tr>
	<td colspan=\"2\">". $out->input_form("hidden","oldname",KWL_PrepareHtml($user['name'])) .
                    $out->input_form("hidden","uid",$user['uid']) .
                    $out->input_form("submit","act", _USER_EDIT) .
                    $out->input_form("submit","act", _USER_KILL) ."</td></tr>".
                    $out->table_end() . $out->form_end();
KWL_DrawMain($A);
}

include("../include/footer.inc.php");
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/user.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("$CONF[G_PATH]/include/kmod/user_list/index.php");
set_time_limit(0);
ini_set('max_execution_time',0);

unset($user);
unset($login);

settype($act, "string");
settype($uid, "integer");
settype($where, "string");
settype($index, "string");
settype($opt, "string");

if ($act == _USER_ADD) {
	KWL_CheckNewUser($name,$email);
	$pass = trim($pass);
	$sql  = "INSERT INTO T_Users (user_level, name, pass, email, rdate) ";
	$sql .= "VALUES ($user_level, '$name', '". crypt($pass) ."', '$email', now())";
	if (SqlQuery($sql)) {
		$msg = _USER_ADDED;
		if ($mailtouser) KWL_MailToUser($name,$pass,$email);
	} else KWL_ShowError(_SQL_ERROR);

} else if ($act == "edit") {
	if ($uid) $user = KWL_GetUserInfo("uid",$uid);

} else if ($act == _USER_EDIT) {
   
	if ($name != $oldname)
	 if (KWL_GetUserInfo("name",$name)) KWL_ShowError(_USER_REGISTER3);
	$sql = "UPDATE T_Users SET user_level = '$user_level', name = '$name', ";
	$sql .= "email = '$email' ";
	if ($passwd) $sql .= ", pass = '". crypt($passwd) ."' ";
	$sql .= "WHERE uid = '$uid'";
	if (SqlQuery($sql)) {
      /* change new name for old posts */
      if ($name != $oldname) {
        $sql = "UPDATE T_Stories SET Author = '$name', AuthorEmail = '$email'".
           " WHERE Author = '$oldname' AND AuthorEmail = '$oldemail'";
        SqlQuery($sql);
        $sql = "UPDATE T_Comments SET Author = '$name', AuthorEmail = '$email'".
           " WHERE Author = '$oldname' AND AuthorEmail = '$oldemail'";
        SqlQuery($sql);
      }      
		$msg = _UPDATED_USERDB;
	} else KWL_ShowError(_SQL_ERROR);


} else if ($act == _USER_KILL) {
	$sql = "DELETE FROM T_Users WHERE uid = '$uid'";
	if (SqlQuery($sql)) $msg = _USER_DELETED;
	else KWL_ShowError(_SQL_ERROR);

} else if ($uid) {
	$user = KWL_GetUserInfo("uid",$uid);
}

include("../include/header.inc.php");

$total_user = SqlCount("T_Users");
$moder = SqlCount("T_Users","user_level",1);
$smoder = SqlCount("T_Users","user_level",2);

$out = new KWL_Html;
$A['Heading'] = _USER_ADMIN;
$A['Content'] = "
<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" width=\"100%\">
<tr><td>
<ul>
	<li><a href=\"user.php?act=ulist&opt=n\">". _NORMAL_USER ."</a>: " . ($total_user - ($moder + $smoder)) . "</li>
	<li><a href=\"user.php?act=ulist&opt=m\">". _MODERATOR ."</a>: $moder </li>
	<li><a href=\"user.php?act=ulist&opt=s\">". _SCORE_MODERATOR ."</a>: $smoder </li>
	<li><a href=\"user.php?act=ulist&opt=t\">". _TOTAL ."</a>: $total_user </li>
</ul>
</td></tr></table>".
$out->form_start("admin/user.php","adduser").
$out->table_start("100%",'',0,0,3)."
<tr>
	<td>". _LEVEL .":</td>
   <td>". $out->select("user_level", array (0 => _NORMAL_USER,
                                            1 => _MODERATOR,
                                            2 => _SCORE_MODERATOR),0) ."
</td>
</tr>
<tr>
   <td>* ". _NAME .":</td>
   <td>". $out->input_form("text","name",'',KWL_FormSize(10),50) ."</td>
</tr>   
<tr>
   <td>* ". _EMAIL .":</td>
   <td>". $out->input_form("text","email",'',KWL_FormSize(10),60) ."</td>
</tr>   
<tr>
   <td>* ". _PASSWD .":</td>
   <td>". $out->input_form("text","pass",'',KWL_FormSize(10),13) ."</td>
</tr>   
<tr>
   <td colspan=\"2\">". _SENDMAIL .": ".
   $out->check_box("mailtouser") ."</td>
</tr>   
<tr>
	<td colspan=\"2\">". $out->input_form("submit","act",_USER_ADD) ."</td>
</tr>". $out->table_end() . $out->form_end();
$A['Content'] .= KWL_MakeUserIndex("$CONF[G_URL]/admin/user.php?act=ulist");
KWL_DrawMain($A);

if (!empty($where)) $tmp = htmlspecialchars(stripslashes($index));
else $tmp = "";
$C['Heading'] = "<a name=\"finduser\">". _FIND_USER ."</a>";
$C['Content'] = "<center><br>". $out->form_start("admin/user.php#finduser","finduser").
                $out->input_form("TEXT","index",$tmp,$size['name'],60) ."&nbsp;".
                $out->select("where", array( "name"     => _NAME,
                                             "email"    => _EMAIL,
                                             "url"      => _URL,
                                             "user_sig" => _USER_SIG,
                                             "profile"  => _USER_PROF ), $where).
                $out->input_form("HIDDEN","what","finduser").
                $out->input_form("SUBMIT",'',_FIND).
                $out->form_end() . "</center><br>";
KWL_DrawMain($C);
unset($C);

if ($index) user_list_admin("",$index);
elseif ($act == "ulist") user_list_admin($opt);
elseif (is_array($user)) edit_user($user);

function user_list_admin($opt,$index="",$plimit=15) {
	global $CONF,$page,$where;

	$sql = "FROM T_Users WHERE ";	
	if (!empty($index)) {
      if (!empty($where)) {
         $sql .= "($where LIKE \"%". $index ."%\") ORDER BY uid DESC";
      } elseif(KWL_CheckHangul($index)) {
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = "ī";
			if($index == "ī") $r = "Ÿ";
			if($index == "Ÿ") $r = "";
			if($index == "") $r = "";
			if($index == "") $r = chr(0xfe);
			$sql .= "binary name BETWEEN binary '$index' AND binary '$r'";
		} elseif ($index == "other") {
         $sql .= "name REGEXP \"^\[1-9\.]\" ORDER BY uid DESC";
      } else $sql .= "name REGEXP \"^". $index ."\" ORDER BY uid DESC";
		$link = "user.php?index=$index";
	} else {
		if ($opt == "m") $sql .= "user_level = 1 ";
		elseif ($opt == "n") $sql .= "user_level = 0 ";
		elseif ($opt == "s") $sql .= "user_level = 2 ";
		else $sql .= "uid > 0 ";
		$sql .= "ORDER BY uid ASC ";
		$link = "user.php?act=ulist&opt=$opt";
	}

	if (empty($page)) $page = 1;
	$num_user = SqlResult("SELECT COUNT(*)" . $sql);
	$page_start = ($plimit * $page) - $plimit;
	$blah = KWL_npLink($num_user,$page,$link,$plimit);	
	
	$C['Content'] = $blah ? "<CENTER>$blah</CENTER>\n" : "";
	
	$result = SqlQuery("SELECT * " . $sql . " LIMIT $page_start,$plimit");

	$C['Content'] .= "<table border=\"1\" cellspacing=\"0\" cellpadding=\"3\" width=\"100%\"><tr>
	<th>Uid</th>
	<th>". _LEVEL ."</th>
	<th>". _NAME ."</th>
	<th>". _EMAIL ."</th>
	<th>". _RDATE ."</th>
	<th>&nbsp;</th>";
	while ($A = mysql_fetch_array($result)) {
		if ($A['user_level'] == 0) $tmp = _NORMAL_USER;
		elseif ($A['user_level'] == 1) $tmp = _MODERATOR;
		else $tmp = _SCORE_MODERATOR;
		$C['Content'] .= "<tr>
		<td>$A[uid]</td>
		<td>$tmp</td>
		<td><a href=\"$CONF[G_URL]/profiles.php?uid=$A[uid]\">". KWL_PrepareHtml($A['name']) ."</a></td>
		<td>$A[email]</td>
		<td>$A[rdate]</td>
		<td><a onclick=\"return getconfirm();\" href=\"user.php?act=". _USER_KILL ."&amp;uid=$A[uid]\"><img src=\"$CONF[img_url]/kill.gif\" alt=\"kill\" border=\"0\" /></a>&nbsp;<a href=\"user.php?act=edit&amp;uid=$A[uid]#edituser\"><img src=\"$CONF[img_url]/edit.gif\" alt=\"edit\" border=\"0\" /></a></td>";
	}
$C['Heading'] = "User List";
$C['Content'] .= "</tr></table>";
if ($blah) $C['Content'] .= "<center>$blah</center>\n";
KWL_DrawMain($C);
}

function edit_user($user) {

$out = new KWL_Html;
$A['Heading'] = "<a name=\"edituser\">". _USER_INFO ."</a>";
$A['Content'] = $out->form_start("admin/user.php","edituser") .
                $out->table_start("100%",'',0,0,3) ."
<tr>
	<td>Uid:</td><td>$user[uid]</td>
</tr>   
<tr>
	<td>". _RDATE ."</td>
   <td>$user[rdate]</td>
</tr>
<tr>
	<td>". _LEVEL .":</td>
   <td>". $out->select("user_level",array( 0 => _NORMAL_USER,
                                           1 => _MODERATOR,
                                           2 => _SCORE_MODERATOR ), $user['user_level']) ."
	</td>
</tr>   
<tr>
   <td>". _NAME .":</td>
   <td>". $out->input_form("text","name",KWL_PrepareHtml($user['name']),KWL_FormSize(10),50) ."
   </td>
</tr>   
<tr>
   <td>". _EMAIL .":</td>
   <td>". $out->input_form("text","email",KWL_PrepareHtml($user['email']),KWL_FormSize(10),60) ."   </td>
</tr>   
<tr>
   <td>". _PASSWD .":</td>
   <td>". $out->input_form("text","passwd",'',KWL_FormSize(10),13) ."
   <br />(". _PASS_CHANGE .")</td>
</tr>   
<tr>
	<td colspan=\"2\">". $out->input_form("hidden","oldname",KWL_PrepareHtml($user['name'])) .
                    $out->input_form("hidden","oldemail",KWL_PrepareHtml($user['email'])).
                    $out->input_form("hidden","uid",$user['uid']) .
                    $out->input_form("submit","act", _USER_EDIT) .
                    $out->input_form("submit","act", _USER_KILL) ."</td></tr>".
                    $out->table_end() . $out->form_end();
KWL_DrawMain($A);
}

include("../include/footer.inc.php");
?>
